@@ -3,7 +3,7 @@ Wrapper for `git diff` command.
 """
 from textwrap import dedent
 
-from diff_cover.command_runner import execute, CommandError
+from diff_cover.command_runner import CommandError, execute
 
 
 class GitDiffError(Exception):
@@ -79,8 +79,7 @@ class GitDiffTool:
                     """
                     )
                 )
-            else:
-                raise
+            raise
 
     def diff_unstaged(self):
         """
@@ -103,3 +102,9 @@ class GitDiffTool:
         return execute(self._default_git_args + self._default_diff_args + ["--cached"])[
             0
         ]
+
+    def untracked(self):
+        """Return the untracked files."""
+        output = execute(["git", "ls-files", "--exclude-standard", "--others"])[0]
+        output = output.strip()
+        return output.split("\n") if output else []
